<?php

namespace Eform\Filing\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Filing\Actions\FilingAction;
use Eform\Filing\Http\Requests\FilingActionRequest;
use Eform\Filing\Http\Resources\FilingResource;
use Eform\Filing\Models\Filing;

/**
 * Admin web controller class.
 */
class FilingActionController extends BaseController
{

    /**
     * Action controller function for filing.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FilingActionRequest $request, Filing $filing, $action)
    {
        try {
            $request = $request->all();
            $filing = FilingAction::run($action, $filing, $request);

            $data = new FilingResource($filing);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('filing::filing.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('filing/filing/' . $filing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('filing/filing/' . $filing->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
