<?php

namespace Eform\Filing\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Eform\Filing\Actions\FilingExim;
use Eform\Filing\Http\Requests\FilingEximRequest;

/**
 * Admin web controller class.
 */
class FilingEximController extends BaseController
{
    /**
     * Action controller function for filing.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FilingEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = FilingExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('filing:filing.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('filing/filing/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('filing/filing/' . $exim))
                ->redirect();
        }
    }
}
