<?php
namespace Eform\Filing\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Eform\Filing\Events\FilingAction as FilingActionEvent;
use Eform\Filing\Models\Filing;

class FilingAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $filing;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param FilingActionEvent $filing
     */
    public function __construct(FilingActionEvent $filing)
    {
        $this->action = $event->action;
        $this->filing = $filing;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Filing Approved - ' . config('app.name'))
            ->view('filing::filing.email.action', ['data' => $this->filing]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
