<?php

namespace Eform\Filing\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Eform\Filing\Models\Filing;

class FilingPolicy
{

    use FilingAction;
    use FilingExim;

    /**
     * Determine if the given user can view the filing.
     *
     * @param Authenticatable $user
     * @param Filing $filing
     *
     * @return bool
     */
    public function view(Authenticatable $user, Filing $filing)
    {
        if ($authUser->canDo('filing.filing.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $filing->is_owner;
    }

    /**
     * Determine if the given user can create a filing.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('filing.filing.create');
    }

    /**
     * Determine if the given user can update the given filing.
     *
     * @param Authenticatable $user
     * @param Filing $filing
     *
     * @return bool
     */
    public function update(Authenticatable $user, Filing $filing)
    {
        if ($user->canDo('filing.filing.edit') && $user->isAdmin()) {
            return true;
        }

        return $filing->is_owner;
    }

    /**
     * Determine if the given user can delete the given filing.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Filing $filing)
    {
        return $filing->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
